@@ -26,10 +26,12 @@ from mypy_boto3_docdb.paginator import (
     DescribeDBInstancesPaginator,
     DescribeDBSubnetGroupsPaginator,
     DescribeEventsPaginator,
+    DescribeEventSubscriptionsPaginator,
     DescribeOrderableDBInstanceOptionsPaginator,
     DescribePendingMaintenanceActionsPaginator,
 )
 from mypy_boto3_docdb.type_defs import (
+    AddSourceIdentifierToSubscriptionResultTypeDef,
     ApplyPendingMaintenanceActionResultTypeDef,
     CertificateMessageTypeDef,
     CloudwatchLogsExportConfigurationTypeDef,
@@ -40,6 +42,7 @@ from mypy_boto3_docdb.type_defs import (
     CreateDBClusterSnapshotResultTypeDef,
     CreateDBInstanceResultTypeDef,
     CreateDBSubnetGroupResultTypeDef,
+    CreateEventSubscriptionResultTypeDef,
     DBClusterMessageTypeDef,
     DBClusterParameterGroupDetailsTypeDef,
     DBClusterParameterGroupNameMessageTypeDef,
@@ -51,20 +54,24 @@ from mypy_boto3_docdb.type_defs import (
     DeleteDBClusterResultTypeDef,
     DeleteDBClusterSnapshotResultTypeDef,
     DeleteDBInstanceResultTypeDef,
+    DeleteEventSubscriptionResultTypeDef,
     DescribeDBClusterSnapshotAttributesResultTypeDef,
     DescribeEngineDefaultClusterParametersResultTypeDef,
     EventCategoriesMessageTypeDef,
     EventsMessageTypeDef,
+    EventSubscriptionsMessageTypeDef,
     FailoverDBClusterResultTypeDef,
     FilterTypeDef,
     ModifyDBClusterResultTypeDef,
     ModifyDBClusterSnapshotAttributeResultTypeDef,
     ModifyDBInstanceResultTypeDef,
     ModifyDBSubnetGroupResultTypeDef,
+    ModifyEventSubscriptionResultTypeDef,
     OrderableDBInstanceOptionsMessageTypeDef,
     ParameterTypeDef,
     PendingMaintenanceActionsMessageTypeDef,
     RebootDBInstanceResultTypeDef,
+    RemoveSourceIdentifierFromSubscriptionResultTypeDef,
     RestoreDBClusterFromSnapshotResultTypeDef,
     RestoreDBClusterToPointInTimeResultTypeDef,
     StartDBClusterResultTypeDef,
@@ -115,6 +122,7 @@ class Exceptions:
     DBSubnetGroupQuotaExceededFault: Type[BotocoreClientError]
     DBSubnetQuotaExceededFault: Type[BotocoreClientError]
     DBUpgradeDependencyFailureFault: Type[BotocoreClientError]
+    EventSubscriptionQuotaExceededFault: Type[BotocoreClientError]
     InstanceQuotaExceededFault: Type[BotocoreClientError]
     InsufficientDBClusterCapacityFault: Type[BotocoreClientError]
     InsufficientDBInstanceCapacityFault: Type[BotocoreClientError]
@@ -127,41 +135,56 @@ class Exceptions:
     InvalidDBSnapshotStateFault: Type[BotocoreClientError]
     InvalidDBSubnetGroupStateFault: Type[BotocoreClientError]
     InvalidDBSubnetStateFault: Type[BotocoreClientError]
+    InvalidEventSubscriptionStateFault: Type[BotocoreClientError]
     InvalidRestoreFault: Type[BotocoreClientError]
     InvalidSubnet: Type[BotocoreClientError]
     InvalidVPCNetworkStateFault: Type[BotocoreClientError]
     KMSKeyNotAccessibleFault: Type[BotocoreClientError]
     ResourceNotFoundFault: Type[BotocoreClientError]
+    SNSInvalidTopicFault: Type[BotocoreClientError]
+    SNSNoAuthorizationFault: Type[BotocoreClientError]
+    SNSTopicArnNotFoundFault: Type[BotocoreClientError]
     SharedSnapshotQuotaExceededFault: Type[BotocoreClientError]
     SnapshotQuotaExceededFault: Type[BotocoreClientError]
+    SourceNotFoundFault: Type[BotocoreClientError]
     StorageQuotaExceededFault: Type[BotocoreClientError]
     StorageTypeNotSupportedFault: Type[BotocoreClientError]
     SubnetAlreadyInUse: Type[BotocoreClientError]
+    SubscriptionAlreadyExistFault: Type[BotocoreClientError]
+    SubscriptionCategoryNotFoundFault: Type[BotocoreClientError]
+    SubscriptionNotFoundFault: Type[BotocoreClientError]
 
 
 class DocDBClient:
     """
-    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client)
+    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client)
     """
 
     meta: ClientMeta
     exceptions: Exceptions
 
+    def add_source_identifier_to_subscription(
+        self, SubscriptionName: str, SourceIdentifier: str
+    ) -> AddSourceIdentifierToSubscriptionResultTypeDef:
+        """
+        [Client.add_source_identifier_to_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.add_source_identifier_to_subscription)
+        """
+
     def add_tags_to_resource(self, ResourceName: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
+        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
         """
 
     def apply_pending_maintenance_action(
         self, ResourceIdentifier: str, ApplyAction: str, OptInType: str
     ) -> ApplyPendingMaintenanceActionResultTypeDef:
         """
-        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
+        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.can_paginate)
         """
 
     def copy_db_cluster_parameter_group(
@@ -172,7 +195,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
-        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
+        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
         """
 
     def copy_db_cluster_snapshot(
@@ -186,7 +209,7 @@ class DocDBClient:
         SourceRegion: str = None,
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
-        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
+        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
         """
 
     def create_db_cluster(
@@ -213,7 +236,7 @@ class DocDBClient:
         SourceRegion: str = None,
     ) -> CreateDBClusterResultTypeDef:
         """
-        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.create_db_cluster)
+        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_db_cluster)
         """
 
     def create_db_cluster_parameter_group(
@@ -224,7 +247,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
-        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
+        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
         """
 
     def create_db_cluster_snapshot(
@@ -234,7 +257,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
-        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
+        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
         """
 
     def create_db_instance(
@@ -250,7 +273,7 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> CreateDBInstanceResultTypeDef:
         """
-        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.create_db_instance)
+        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_db_instance)
         """
 
     def create_db_subnet_group(
@@ -261,7 +284,21 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
-        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
+        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
+        """
+
+    def create_event_subscription(
+        self,
+        SubscriptionName: str,
+        SnsTopicArn: str,
+        SourceType: str = None,
+        EventCategories: List[str] = None,
+        SourceIds: List[str] = None,
+        Enabled: bool = None,
+        Tags: List["TagTypeDef"] = None,
+    ) -> CreateEventSubscriptionResultTypeDef:
+        """
+        [Client.create_event_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.create_event_subscription)
         """
 
     def delete_db_cluster(
@@ -271,29 +308,36 @@ class DocDBClient:
         FinalDBSnapshotIdentifier: str = None,
     ) -> DeleteDBClusterResultTypeDef:
         """
-        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
+        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
         """
 
     def delete_db_cluster_parameter_group(self, DBClusterParameterGroupName: str) -> None:
         """
-        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
+        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
         """
 
     def delete_db_cluster_snapshot(
         self, DBClusterSnapshotIdentifier: str
     ) -> DeleteDBClusterSnapshotResultTypeDef:
         """
-        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
+        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
         """
 
     def delete_db_instance(self, DBInstanceIdentifier: str) -> DeleteDBInstanceResultTypeDef:
         """
-        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.delete_db_instance)
+        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_db_instance)
         """
 
     def delete_db_subnet_group(self, DBSubnetGroupName: str) -> None:
         """
-        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
+        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
+        """
+
+    def delete_event_subscription(
+        self, SubscriptionName: str
+    ) -> DeleteEventSubscriptionResultTypeDef:
+        """
+        [Client.delete_event_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.delete_event_subscription)
         """
 
     def describe_certificates(
@@ -304,7 +348,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> CertificateMessageTypeDef:
         """
-        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_certificates)
+        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_certificates)
         """
 
     def describe_db_cluster_parameter_groups(
@@ -315,7 +359,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupsMessageTypeDef:
         """
-        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
+        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
         """
 
     def describe_db_cluster_parameters(
@@ -327,14 +371,14 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupDetailsTypeDef:
         """
-        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
+        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
         """
 
     def describe_db_cluster_snapshot_attributes(
         self, DBClusterSnapshotIdentifier: str
     ) -> DescribeDBClusterSnapshotAttributesResultTypeDef:
         """
-        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
+        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
         """
 
     def describe_db_cluster_snapshots(
@@ -349,7 +393,7 @@ class DocDBClient:
         IncludePublic: bool = None,
     ) -> DBClusterSnapshotMessageTypeDef:
         """
-        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
+        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
         """
 
     def describe_db_clusters(
@@ -360,7 +404,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterMessageTypeDef:
         """
-        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
+        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
         """
 
     def describe_db_engine_versions(
@@ -376,7 +420,7 @@ class DocDBClient:
         ListSupportedTimezones: bool = None,
     ) -> DBEngineVersionMessageTypeDef:
         """
-        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
+        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
         """
 
     def describe_db_instances(
@@ -387,7 +431,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBInstanceMessageTypeDef:
         """
-        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_instances)
+        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_instances)
         """
 
     def describe_db_subnet_groups(
@@ -398,7 +442,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBSubnetGroupMessageTypeDef:
         """
-        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
+        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
         """
 
     def describe_engine_default_cluster_parameters(
@@ -409,14 +453,25 @@ class DocDBClient:
         Marker: str = None,
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
         """
-        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
+        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
         """
 
     def describe_event_categories(
         self, SourceType: str = None, Filters: List[FilterTypeDef] = None
     ) -> EventCategoriesMessageTypeDef:
         """
-        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_event_categories)
+        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_event_categories)
+        """
+
+    def describe_event_subscriptions(
+        self,
+        SubscriptionName: str = None,
+        Filters: List[FilterTypeDef] = None,
+        MaxRecords: int = None,
+        Marker: str = None,
+    ) -> EventSubscriptionsMessageTypeDef:
+        """
+        [Client.describe_event_subscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_event_subscriptions)
         """
 
     def describe_events(
@@ -439,7 +494,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> EventsMessageTypeDef:
         """
-        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_events)
+        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_events)
         """
 
     def describe_orderable_db_instance_options(
@@ -454,7 +509,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> OrderableDBInstanceOptionsMessageTypeDef:
         """
-        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
+        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
         """
 
     def describe_pending_maintenance_actions(
@@ -465,14 +520,14 @@ class DocDBClient:
         MaxRecords: int = None,
     ) -> PendingMaintenanceActionsMessageTypeDef:
         """
-        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
+        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
         """
 
     def failover_db_cluster(
         self, DBClusterIdentifier: str = None, TargetDBInstanceIdentifier: str = None
     ) -> FailoverDBClusterResultTypeDef:
         """
-        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
+        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
         """
 
     def generate_presigned_url(
@@ -483,14 +538,14 @@ class DocDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
         """
 
     def list_tags_for_resource(
         self, ResourceName: str, Filters: List[FilterTypeDef] = None
     ) -> TagListMessageTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
         """
 
     def modify_db_cluster(
@@ -510,14 +565,14 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> ModifyDBClusterResultTypeDef:
         """
-        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
+        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
         """
 
     def modify_db_cluster_parameter_group(
         self, DBClusterParameterGroupName: str, Parameters: List["ParameterTypeDef"]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
+        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
         """
 
     def modify_db_cluster_snapshot_attribute(
@@ -528,7 +583,7 @@ class DocDBClient:
         ValuesToRemove: List[str] = None,
     ) -> ModifyDBClusterSnapshotAttributeResultTypeDef:
         """
-        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
+        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
         """
 
     def modify_db_instance(
@@ -543,26 +598,45 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> ModifyDBInstanceResultTypeDef:
         """
-        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.modify_db_instance)
+        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_db_instance)
         """
 
     def modify_db_subnet_group(
         self, DBSubnetGroupName: str, SubnetIds: List[str], DBSubnetGroupDescription: str = None
     ) -> ModifyDBSubnetGroupResultTypeDef:
         """
-        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
+        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
+        """
+
+    def modify_event_subscription(
+        self,
+        SubscriptionName: str,
+        SnsTopicArn: str = None,
+        SourceType: str = None,
+        EventCategories: List[str] = None,
+        Enabled: bool = None,
+    ) -> ModifyEventSubscriptionResultTypeDef:
+        """
+        [Client.modify_event_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.modify_event_subscription)
         """
 
     def reboot_db_instance(
         self, DBInstanceIdentifier: str, ForceFailover: bool = None
     ) -> RebootDBInstanceResultTypeDef:
         """
-        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
+        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
+        """
+
+    def remove_source_identifier_from_subscription(
+        self, SubscriptionName: str, SourceIdentifier: str
+    ) -> RemoveSourceIdentifierFromSubscriptionResultTypeDef:
+        """
+        [Client.remove_source_identifier_from_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.remove_source_identifier_from_subscription)
         """
 
     def remove_tags_from_resource(self, ResourceName: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
+        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
         """
 
     def reset_db_cluster_parameter_group(
@@ -572,7 +646,7 @@ class DocDBClient:
         Parameters: List["ParameterTypeDef"] = None,
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
+        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
         """
 
     def restore_db_cluster_from_snapshot(
@@ -591,7 +665,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterFromSnapshotResultTypeDef:
         """
-        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
+        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
         """
 
     def restore_db_cluster_to_point_in_time(
@@ -609,17 +683,17 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterToPointInTimeResultTypeDef:
         """
-        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
+        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
         """
 
     def start_db_cluster(self, DBClusterIdentifier: str) -> StartDBClusterResultTypeDef:
         """
-        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.start_db_cluster)
+        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.start_db_cluster)
         """
 
     def stop_db_cluster(self, DBClusterIdentifier: str) -> StopDBClusterResultTypeDef:
         """
-        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
+        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
         """
 
     @overload
@@ -627,7 +701,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_certificates"]
     ) -> DescribeCertificatesPaginator:
         """
-        [Paginator.DescribeCertificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)
+        [Paginator.DescribeCertificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)
         """
 
     @overload
@@ -635,7 +709,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameter_groups"]
     ) -> DescribeDBClusterParameterGroupsPaginator:
         """
-        [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)
+        [Paginator.DescribeDBClusterParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)
         """
 
     @overload
@@ -643,7 +717,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameters"]
     ) -> DescribeDBClusterParametersPaginator:
         """
-        [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)
+        [Paginator.DescribeDBClusterParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)
         """
 
     @overload
@@ -651,7 +725,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_snapshots"]
     ) -> DescribeDBClusterSnapshotsPaginator:
         """
-        [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)
+        [Paginator.DescribeDBClusterSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)
         """
 
     @overload
@@ -659,7 +733,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_clusters"]
     ) -> DescribeDBClustersPaginator:
         """
-        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
+        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
         """
 
     @overload
@@ -667,7 +741,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_engine_versions"]
     ) -> DescribeDBEngineVersionsPaginator:
         """
-        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
+        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
         """
 
     @overload
@@ -675,7 +749,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_instances"]
     ) -> DescribeDBInstancesPaginator:
         """
-        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
+        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
         """
 
     @overload
@@ -683,13 +757,21 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_subnet_groups"]
     ) -> DescribeDBSubnetGroupsPaginator:
         """
-        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["describe_event_subscriptions"]
+    ) -> DescribeEventSubscriptionsPaginator:
+        """
+        [Paginator.DescribeEventSubscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeEventSubscriptions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_events"]) -> DescribeEventsPaginator:
         """
-        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
+        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
         """
 
     @overload
@@ -697,7 +779,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_orderable_db_instance_options"]
     ) -> DescribeOrderableDBInstanceOptionsPaginator:
         """
-        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
+        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
         """
 
     @overload
@@ -705,7 +787,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_pending_maintenance_actions"]
     ) -> DescribePendingMaintenanceActionsPaginator:
         """
-        [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)
+        [Paginator.DescribePendingMaintenanceActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)
         """
 
     @overload
@@ -713,11 +795,11 @@ class DocDBClient:
         self, waiter_name: Literal["db_instance_available"]
     ) -> DBInstanceAvailableWaiter:
         """
-        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["db_instance_deleted"]) -> DBInstanceDeletedWaiter:
         """
-        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.37/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.40/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
         """
